#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "dialog.h"
#include "settingsdlg.h"
#include <QDateTime>
#include <QMessageBox>
#include <QStyleOption>
#include <QCoreApplication>
#include <QMovie>
#include <QDialog>
#include <QSettings>



#ifdef Q_WS_HILDON
    #include <X11/Xlib.h>
    #include <X11/Xatom.h>
    #include <QtGui/QX11Info>
#endif








MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(0, Qt::FramelessWindowHint),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    SetupThisUi();
}



void MainWindow::showEvent(QShowEvent* event)
{
#ifdef Q_WS_HILDON
    QCoreApplication::instance()->setApplicationName("simplenotewidget");

    Atom homeAppletAto = XInternAtom(QX11Info::display(), "_HILDON_WM_WINDOW_TYPE_HOME_APPLET", false);
    Atom utf8Atom = XInternAtom(QX11Info::display(), "UTF8_STRING", false);

    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false), XA_ATOM, 32, PropModeReplace, (unsigned char *) &homeAppletAto, 1);
    QByteArray id (QCoreApplication::instance()->applicationName().remove(' ').toUtf8());
    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_ID", false), utf8Atom, 8,PropModeReplace, (unsigned char *)id.constData(), id.length());
    int settings = 0;
    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false), XA_CARDINAL, 32, PropModeReplace, (unsigned char*)&settings, 1);
    bool all_desktops =false;
    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_DISPLAY_ON_ALL_VIEWS", false),XA_CARDINAL, 32, PropModeReplace,(unsigned char *) &all_desktops, 1);

#endif

}



#ifdef Q_WS_HILDON
    //Filter show setting requests
    bool MainWindow::x11Event(XEvent* event)
    {
        static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
        if (event->xclient.message_type == appletShowSettingAtom )
        {
          settingsdlg *w;
          w = new settingsdlg(0);
          w->exec();
          SetupThisUi();
          delete w;
          return true;
        }
     return false;
    }
#endif

void MainWindow::on_pbEdit_clicked()
{
        Dialog *w;
        w = new Dialog(0);

        //settingsdlg *w;
        //w = new settingsdlg(0);
        w->exec();
        SetupThisUi();
        delete w;
}


void MainWindow::SetupThisUi()
{

    QSettings *oSettings;
    oSettings = new QSettings("janbergmann", "simplenotewidget");
    QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
    QColor cltextedit = oSettings->value("txtcolor", QColor(0,0,0)).value<QColor>();
    int bgcoloralpha = oSettings->value("bgcoloralpha", int(180)).toInt();
    cldefault.setAlpha(bgcoloralpha);
    int fontSizeIndex = oSettings->value("fontsize", int(1)).toInt();
    QString fontFamilyName = oSettings->value("fontfamily", "Nokia Sans SemiBold").toString();

    switch(fontSizeIndex)
    {
     case 0: fontSizeIndex = 6;
             break;
     case 1: fontSizeIndex = 8;
             break;
     case 2: fontSizeIndex = 10;
             break;
     case 3: fontSizeIndex = 12;
             break;
     case 4: fontSizeIndex = 16;
             break;
     case 5: fontSizeIndex = 24;
             break;
     case 6: fontSizeIndex = 32;
    }

    QPalette pal = this->palette();
    this->setAttribute(Qt::WA_TranslucentBackground);
    this->setAttribute(Qt::WA_NoSystemBackground, false);

    pal.setColor(QPalette::Window, cldefault);
    this->setPalette(pal);
    this->ensurePolished();
    this->setAttribute(Qt::WA_StyledBackground, false);


    QSize oMovSize;
    oMovSize.setHeight(21);
    oMovSize.setWidth(21);
    ui->lbicon->setText("");
    QMovie *movie = new QMovie(":/img/res/pin.png");
    movie->setScaledSize(oMovSize);
    movie->setBackgroundColor(Qt::transparent);
    ui->lbicon->setMovie(movie);
    ui->lbicon->show();
    movie->start();



    ui->teMain->setFrameShadow(QFrame::Plain);
    ui->teMain->setFrameShape(QFrame::NoFrame);
    ui->teMain->setPalette(QPalette(cltextedit,cldefault,cldefault,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
    ui->teMain->setFontFamily(fontFamilyName);
    ui->teMain->setFontPointSize(fontSizeIndex);
    ui->teMain->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
    ui->teMain->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    ui->teMain->setReadOnly(true);


    QVariant vRed (cltextedit.red());
    QVariant vGreen (cltextedit.green());
    QVariant vBlue (cltextedit.blue());

    ui->teMain->setStyleSheet( "background-color: rgba( " + vRed.toString() + ", " + vGreen.toString() +  ", " + vBlue.toString() + ", 0% );" );
    ui->teMain->setPalette(QPalette(cltextedit,cldefault,cldefault,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
    //ui->teMain->repaint();



    ui->lblDate->setLayoutDirection(Qt::RightToLeft);
    ui->lblDate->setPalette(QPalette(cltextedit,cltextedit,cltextedit,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
    ui->lblDate->setFont(QFont(fontFamilyName,10,10));


    QPalette p = palette();
    ui->pbEdit->setPalette(p);
    ui->pbEdit->setStyleSheet( "background-color: rgba( 255, 255, 255, 0% );" );
    ui->pbEdit->setText("");
    ui->pbEdit->setFlat(true);


#ifdef Q_WS_HILDON
       this->setProperty("FingerScrollable", true);
       ui->teMain->setFocusPolicy(Qt::StrongFocus);
       this->setFocusPolicy(Qt::StrongFocus);
       ui->teMain->setProperty("FingerScrollable", true);
#endif

   ui->teMain->setText(oSettings->value("note","").toString());
   ui->lblDate->setText(oSettings->value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());

   delete oSettings;


   ui->centralWidget->repaint();
   this->repaint();

}



MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}





